Module: RubyEncoderLoader

Defined in:
lib/rgloader.rb,
lib/rgloader/version.rb

Overview

RubyEncoder v1.0 loader

Get the version and platform information for requiring loading proper loader native module.

For ruby 1.8.x there no prefix in module name. So module name will be

* rgloader.<platform>.[x68_64]

As far I understand, for 1.9.x there two types of modules. Generic and Specific one.

From my personal expirience (Oct, 2012) Generic modules, if they really designed to work with all versions in 1.9.x branch, not allways works.

For example, when there was no loaders for 1.9.3, generic module raised and exception, if you tried to load it. But anyway, from original loader code it’s clear that RubyEncoder tries to find Specific module, but if it fails it tries to load Generic one.

For Generic modules “19” prefix is used:

* rgloader19.<platform>.[x68_64]

For Specific modules “19x” prefix is used. For example, for 1.9.3 it will be something like:

* rgloader193.<platform>.[x68_64]

Defined Under Namespace

Classes: LoadError

Constant Summary collapse

VERSION =
"2.1"